# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DatabaseWriteStaticRoleRequest(BaseModel):
    """
    DatabaseWriteStaticRoleRequest
    """ # noqa: E501
    credential_config: Optional[Dict[str, Any]] = Field(default=None, description="The configuration for the given credential_type.")
    credential_type: Optional[StrictStr] = Field(default='password', description="The type of credential to manage. Options include: 'password', 'rsa_private_key'. Defaults to 'password'.")
    db_name: Optional[StrictStr] = Field(default=None, description="Name of the database this role acts on.")
    rotation_period: Optional[StrictStr] = Field(default=None, description="Period for automatic credential rotation of the given username. Not valid unless used with \"username\". Mutually exclusive with \"rotation_schedule.\"")
    rotation_schedule: Optional[StrictStr] = Field(default=None, description="Schedule for automatic credential rotation of the given username. Mutually exclusive with \"rotation_period.\"")
    rotation_statements: Optional[List[StrictStr]] = Field(default=None, description="Specifies the database statements to be executed to rotate the accounts credentials. Not every plugin type will support this functionality. See the plugin's API page for more information on support and formatting for this parameter.")
    rotation_window: Optional[StrictStr] = Field(default=None, description="The window of time in which rotations are allowed to occur starting from a given \"rotation_schedule\". Requires \"rotation_schedule\" to be specified")
    username: Optional[StrictStr] = Field(default=None, description="Name of the static user account for Vault to manage. Requires \"rotation_period\" to be specified")
    __properties: ClassVar[List[str]] = ["credential_config", "credential_type", "db_name", "rotation_period", "rotation_schedule", "rotation_statements", "rotation_window", "username"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DatabaseWriteStaticRoleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DatabaseWriteStaticRoleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "credential_config": obj.get("credential_config"),
            "credential_type": obj.get("credential_type") if obj.get("credential_type") is not None else 'password',
            "db_name": obj.get("db_name"),
            "rotation_period": obj.get("rotation_period"),
            "rotation_schedule": obj.get("rotation_schedule"),
            "rotation_statements": obj.get("rotation_statements"),
            "rotation_window": obj.get("rotation_window"),
            "username": obj.get("username")
        })
        return _obj


