# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.transit_import_key_request import TransitImportKeyRequest

class TestTransitImportKeyRequest(unittest.TestCase):
    """TransitImportKeyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransitImportKeyRequest:
        """Test TransitImportKeyRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TransitImportKeyRequest`
        """
        model = TransitImportKeyRequest()
        if include_optional:
            return TransitImportKeyRequest(
                allow_plaintext_backup = True,
                allow_rotation = True,
                auto_rotate_period = '0',
                ciphertext = '',
                context = '',
                derived = True,
                exportable = True,
                hash_function = 'SHA256',
                public_key = '',
                type = 'aes256-gcm96'
            )
        else:
            return TransitImportKeyRequest(
        )
        """

    def testTransitImportKeyRequest(self):
        """Test TransitImportKeyRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
