# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.kerberos_configure_ldap_request import KerberosConfigureLdapRequest

class TestKerberosConfigureLdapRequest(unittest.TestCase):
    """KerberosConfigureLdapRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KerberosConfigureLdapRequest:
        """Test KerberosConfigureLdapRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KerberosConfigureLdapRequest`
        """
        model = KerberosConfigureLdapRequest()
        if include_optional:
            return KerberosConfigureLdapRequest(
                anonymous_group_search = True,
                binddn = '',
                bindpass = '',
                case_sensitive_names = True,
                certificate = '',
                client_tls_cert = '',
                client_tls_key = '',
                connection_timeout = '30s',
                deny_null_bind = True,
                dereference_aliases = 'never',
                discoverdn = True,
                groupattr = 'cn',
                groupdn = '',
                groupfilter = '(|(memberUid={{.Username}})(member={{.UserDN}})(uniqueMember={{.UserDN}}))',
                insecure_tls = True,
                max_page_size = 56,
                request_timeout = '90s',
                starttls = True,
                tls_max_version = 'tls12',
                tls_min_version = 'tls12',
                token_bound_cidrs = [
                    ''
                    ],
                token_explicit_max_ttl = '',
                token_max_ttl = '',
                token_no_default_policy = True,
                token_num_uses = 56,
                token_period = '',
                token_policies = [
                    ''
                    ],
                token_ttl = '',
                token_type = 'default-service',
                upndomain = '',
                url = 'ldap://127.0.0.1',
                use_pre111_group_cn_behavior = True,
                use_token_groups = True,
                userattr = 'cn',
                userdn = '',
                userfilter = '({{.UserAttr}}={{.Username}})',
                username_as_alias = True
            )
        else:
            return KerberosConfigureLdapRequest(
        )
        """

    def testKerberosConfigureLdapRequest(self):
        """Test KerberosConfigureLdapRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
