# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_tidy_request import PkiTidyRequest

class TestPkiTidyRequest(unittest.TestCase):
    """PkiTidyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiTidyRequest:
        """Test PkiTidyRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiTidyRequest`
        """
        model = PkiTidyRequest()
        if include_optional:
            return PkiTidyRequest(
                acme_account_safety_buffer = '2592000',
                issuer_safety_buffer = '31536000',
                pause_duration = '0s',
                revocation_queue_safety_buffer = '172800',
                safety_buffer = '259200',
                tidy_acme = True,
                tidy_cert_store = True,
                tidy_cross_cluster_revoked_certs = True,
                tidy_expired_issuers = True,
                tidy_move_legacy_ca_bundle = True,
                tidy_revocation_list = True,
                tidy_revocation_queue = True,
                tidy_revoked_cert_issuer_associations = True,
                tidy_revoked_certs = True
            )
        else:
            return PkiTidyRequest(
        )
        """

    def testPkiTidyRequest(self):
        """Test PkiTidyRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
