# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.userpass_write_user_request import UserpassWriteUserRequest

class TestUserpassWriteUserRequest(unittest.TestCase):
    """UserpassWriteUserRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserpassWriteUserRequest:
        """Test UserpassWriteUserRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserpassWriteUserRequest`
        """
        model = UserpassWriteUserRequest()
        if include_optional:
            return UserpassWriteUserRequest(
                bound_cidrs = [
                    ''
                    ],
                max_ttl = '',
                password = '',
                policies = [
                    ''
                    ],
                token_bound_cidrs = [
                    ''
                    ],
                token_explicit_max_ttl = '',
                token_max_ttl = '',
                token_no_default_policy = True,
                token_num_uses = 56,
                token_period = '',
                token_policies = [
                    ''
                    ],
                token_ttl = '',
                token_type = 'default-service',
                ttl = ''
            )
        else:
            return UserpassWriteUserRequest(
        )
        """

    def testUserpassWriteUserRequest(self):
        """Test UserpassWriteUserRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
