# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.api.auth_api import AuthApi


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthApi()

    def tearDown(self) -> None:
        pass

    def test_ali_cloud_delete_auth_role(self) -> None:
        """Test case for ali_cloud_delete_auth_role

        Create a role and associate policies to it.
        """
        pass

    def test_ali_cloud_list_auth_roles(self) -> None:
        """Test case for ali_cloud_list_auth_roles

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_ali_cloud_list_auth_roles2(self) -> None:
        """Test case for ali_cloud_list_auth_roles2

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_ali_cloud_login(self) -> None:
        """Test case for ali_cloud_login

        Authenticates an RAM entity with Vault.
        """
        pass

    def test_ali_cloud_read_auth_role(self) -> None:
        """Test case for ali_cloud_read_auth_role

        Create a role and associate policies to it.
        """
        pass

    def test_ali_cloud_write_auth_role(self) -> None:
        """Test case for ali_cloud_write_auth_role

        Create a role and associate policies to it.
        """
        pass

    def test_app_role_delete_bind_secret_id(self) -> None:
        """Test case for app_role_delete_bind_secret_id

        """
        pass

    def test_app_role_delete_bound_cidr_list(self) -> None:
        """Test case for app_role_delete_bound_cidr_list

        """
        pass

    def test_app_role_delete_period(self) -> None:
        """Test case for app_role_delete_period

        """
        pass

    def test_app_role_delete_policies(self) -> None:
        """Test case for app_role_delete_policies

        """
        pass

    def test_app_role_delete_role(self) -> None:
        """Test case for app_role_delete_role

        """
        pass

    def test_app_role_delete_secret_id_bound_cidrs(self) -> None:
        """Test case for app_role_delete_secret_id_bound_cidrs

        """
        pass

    def test_app_role_delete_secret_id_num_uses(self) -> None:
        """Test case for app_role_delete_secret_id_num_uses

        """
        pass

    def test_app_role_delete_secret_id_ttl(self) -> None:
        """Test case for app_role_delete_secret_id_ttl

        """
        pass

    def test_app_role_delete_token_bound_cidrs(self) -> None:
        """Test case for app_role_delete_token_bound_cidrs

        """
        pass

    def test_app_role_delete_token_max_ttl(self) -> None:
        """Test case for app_role_delete_token_max_ttl

        """
        pass

    def test_app_role_delete_token_num_uses(self) -> None:
        """Test case for app_role_delete_token_num_uses

        """
        pass

    def test_app_role_delete_token_ttl(self) -> None:
        """Test case for app_role_delete_token_ttl

        """
        pass

    def test_app_role_destroy_secret_id(self) -> None:
        """Test case for app_role_destroy_secret_id

        """
        pass

    def test_app_role_destroy_secret_id2(self) -> None:
        """Test case for app_role_destroy_secret_id2

        """
        pass

    def test_app_role_destroy_secret_id_by_accessor(self) -> None:
        """Test case for app_role_destroy_secret_id_by_accessor

        """
        pass

    def test_app_role_destroy_secret_id_by_accessor2(self) -> None:
        """Test case for app_role_destroy_secret_id_by_accessor2

        """
        pass

    def test_app_role_list_roles(self) -> None:
        """Test case for app_role_list_roles

        """
        pass

    def test_app_role_list_secret_ids(self) -> None:
        """Test case for app_role_list_secret_ids

        """
        pass

    def test_app_role_login(self) -> None:
        """Test case for app_role_login

        """
        pass

    def test_app_role_look_up_secret_id(self) -> None:
        """Test case for app_role_look_up_secret_id

        """
        pass

    def test_app_role_look_up_secret_id_by_accessor(self) -> None:
        """Test case for app_role_look_up_secret_id_by_accessor

        """
        pass

    def test_app_role_read_bind_secret_id(self) -> None:
        """Test case for app_role_read_bind_secret_id

        """
        pass

    def test_app_role_read_bound_cidr_list(self) -> None:
        """Test case for app_role_read_bound_cidr_list

        """
        pass

    def test_app_role_read_local_secret_ids(self) -> None:
        """Test case for app_role_read_local_secret_ids

        """
        pass

    def test_app_role_read_period(self) -> None:
        """Test case for app_role_read_period

        """
        pass

    def test_app_role_read_policies(self) -> None:
        """Test case for app_role_read_policies

        """
        pass

    def test_app_role_read_role(self) -> None:
        """Test case for app_role_read_role

        """
        pass

    def test_app_role_read_role_id(self) -> None:
        """Test case for app_role_read_role_id

        """
        pass

    def test_app_role_read_secret_id_bound_cidrs(self) -> None:
        """Test case for app_role_read_secret_id_bound_cidrs

        """
        pass

    def test_app_role_read_secret_id_num_uses(self) -> None:
        """Test case for app_role_read_secret_id_num_uses

        """
        pass

    def test_app_role_read_secret_id_ttl(self) -> None:
        """Test case for app_role_read_secret_id_ttl

        """
        pass

    def test_app_role_read_token_bound_cidrs(self) -> None:
        """Test case for app_role_read_token_bound_cidrs

        """
        pass

    def test_app_role_read_token_max_ttl(self) -> None:
        """Test case for app_role_read_token_max_ttl

        """
        pass

    def test_app_role_read_token_num_uses(self) -> None:
        """Test case for app_role_read_token_num_uses

        """
        pass

    def test_app_role_read_token_ttl(self) -> None:
        """Test case for app_role_read_token_ttl

        """
        pass

    def test_app_role_tidy_secret_id(self) -> None:
        """Test case for app_role_tidy_secret_id

        """
        pass

    def test_app_role_write_bind_secret_id(self) -> None:
        """Test case for app_role_write_bind_secret_id

        """
        pass

    def test_app_role_write_bound_cidr_list(self) -> None:
        """Test case for app_role_write_bound_cidr_list

        """
        pass

    def test_app_role_write_custom_secret_id(self) -> None:
        """Test case for app_role_write_custom_secret_id

        """
        pass

    def test_app_role_write_period(self) -> None:
        """Test case for app_role_write_period

        """
        pass

    def test_app_role_write_policies(self) -> None:
        """Test case for app_role_write_policies

        """
        pass

    def test_app_role_write_role(self) -> None:
        """Test case for app_role_write_role

        """
        pass

    def test_app_role_write_role_id(self) -> None:
        """Test case for app_role_write_role_id

        """
        pass

    def test_app_role_write_secret_id(self) -> None:
        """Test case for app_role_write_secret_id

        """
        pass

    def test_app_role_write_secret_id_bound_cidrs(self) -> None:
        """Test case for app_role_write_secret_id_bound_cidrs

        """
        pass

    def test_app_role_write_secret_id_num_uses(self) -> None:
        """Test case for app_role_write_secret_id_num_uses

        """
        pass

    def test_app_role_write_secret_id_ttl(self) -> None:
        """Test case for app_role_write_secret_id_ttl

        """
        pass

    def test_app_role_write_token_bound_cidrs(self) -> None:
        """Test case for app_role_write_token_bound_cidrs

        """
        pass

    def test_app_role_write_token_max_ttl(self) -> None:
        """Test case for app_role_write_token_max_ttl

        """
        pass

    def test_app_role_write_token_num_uses(self) -> None:
        """Test case for app_role_write_token_num_uses

        """
        pass

    def test_app_role_write_token_ttl(self) -> None:
        """Test case for app_role_write_token_ttl

        """
        pass

    def test_aws_configure_certificate(self) -> None:
        """Test case for aws_configure_certificate

        """
        pass

    def test_aws_configure_client(self) -> None:
        """Test case for aws_configure_client

        """
        pass

    def test_aws_configure_identity_access_list_tidy_operation(self) -> None:
        """Test case for aws_configure_identity_access_list_tidy_operation

        """
        pass

    def test_aws_configure_identity_integration(self) -> None:
        """Test case for aws_configure_identity_integration

        """
        pass

    def test_aws_configure_identity_whitelist_tidy_operation(self) -> None:
        """Test case for aws_configure_identity_whitelist_tidy_operation

        """
        pass

    def test_aws_configure_role_tag_blacklist_tidy_operation(self) -> None:
        """Test case for aws_configure_role_tag_blacklist_tidy_operation

        """
        pass

    def test_aws_configure_role_tag_deny_list_tidy_operation(self) -> None:
        """Test case for aws_configure_role_tag_deny_list_tidy_operation

        """
        pass

    def test_aws_delete_auth_role(self) -> None:
        """Test case for aws_delete_auth_role

        """
        pass

    def test_aws_delete_certificate_configuration(self) -> None:
        """Test case for aws_delete_certificate_configuration

        """
        pass

    def test_aws_delete_client_configuration(self) -> None:
        """Test case for aws_delete_client_configuration

        """
        pass

    def test_aws_delete_identity_access_list(self) -> None:
        """Test case for aws_delete_identity_access_list

        """
        pass

    def test_aws_delete_identity_access_list_tidy_settings(self) -> None:
        """Test case for aws_delete_identity_access_list_tidy_settings

        """
        pass

    def test_aws_delete_identity_whitelist(self) -> None:
        """Test case for aws_delete_identity_whitelist

        """
        pass

    def test_aws_delete_identity_whitelist_tidy_settings(self) -> None:
        """Test case for aws_delete_identity_whitelist_tidy_settings

        """
        pass

    def test_aws_delete_role_tag_blacklist(self) -> None:
        """Test case for aws_delete_role_tag_blacklist

        """
        pass

    def test_aws_delete_role_tag_blacklist_tidy_settings(self) -> None:
        """Test case for aws_delete_role_tag_blacklist_tidy_settings

        """
        pass

    def test_aws_delete_role_tag_deny_list(self) -> None:
        """Test case for aws_delete_role_tag_deny_list

        """
        pass

    def test_aws_delete_role_tag_deny_list_tidy_settings(self) -> None:
        """Test case for aws_delete_role_tag_deny_list_tidy_settings

        """
        pass

    def test_aws_delete_sts_role(self) -> None:
        """Test case for aws_delete_sts_role

        """
        pass

    def test_aws_list_auth_roles(self) -> None:
        """Test case for aws_list_auth_roles

        """
        pass

    def test_aws_list_auth_roles2(self) -> None:
        """Test case for aws_list_auth_roles2

        """
        pass

    def test_aws_list_certificate_configurations(self) -> None:
        """Test case for aws_list_certificate_configurations

        """
        pass

    def test_aws_list_identity_access_list(self) -> None:
        """Test case for aws_list_identity_access_list

        """
        pass

    def test_aws_list_identity_whitelist(self) -> None:
        """Test case for aws_list_identity_whitelist

        """
        pass

    def test_aws_list_role_tag_blacklists(self) -> None:
        """Test case for aws_list_role_tag_blacklists

        """
        pass

    def test_aws_list_role_tag_deny_lists(self) -> None:
        """Test case for aws_list_role_tag_deny_lists

        """
        pass

    def test_aws_list_sts_role_relationships(self) -> None:
        """Test case for aws_list_sts_role_relationships

        """
        pass

    def test_aws_login(self) -> None:
        """Test case for aws_login

        """
        pass

    def test_aws_read_auth_role(self) -> None:
        """Test case for aws_read_auth_role

        """
        pass

    def test_aws_read_certificate_configuration(self) -> None:
        """Test case for aws_read_certificate_configuration

        """
        pass

    def test_aws_read_client_configuration(self) -> None:
        """Test case for aws_read_client_configuration

        """
        pass

    def test_aws_read_identity_access_list(self) -> None:
        """Test case for aws_read_identity_access_list

        """
        pass

    def test_aws_read_identity_access_list_tidy_settings(self) -> None:
        """Test case for aws_read_identity_access_list_tidy_settings

        """
        pass

    def test_aws_read_identity_integration_configuration(self) -> None:
        """Test case for aws_read_identity_integration_configuration

        """
        pass

    def test_aws_read_identity_whitelist(self) -> None:
        """Test case for aws_read_identity_whitelist

        """
        pass

    def test_aws_read_identity_whitelist_tidy_settings(self) -> None:
        """Test case for aws_read_identity_whitelist_tidy_settings

        """
        pass

    def test_aws_read_role_tag_blacklist(self) -> None:
        """Test case for aws_read_role_tag_blacklist

        """
        pass

    def test_aws_read_role_tag_blacklist_tidy_settings(self) -> None:
        """Test case for aws_read_role_tag_blacklist_tidy_settings

        """
        pass

    def test_aws_read_role_tag_deny_list(self) -> None:
        """Test case for aws_read_role_tag_deny_list

        """
        pass

    def test_aws_read_role_tag_deny_list_tidy_settings(self) -> None:
        """Test case for aws_read_role_tag_deny_list_tidy_settings

        """
        pass

    def test_aws_read_sts_role(self) -> None:
        """Test case for aws_read_sts_role

        """
        pass

    def test_aws_rotate_root_credentials(self) -> None:
        """Test case for aws_rotate_root_credentials

        """
        pass

    def test_aws_tidy_identity_access_list(self) -> None:
        """Test case for aws_tidy_identity_access_list

        """
        pass

    def test_aws_tidy_identity_whitelist(self) -> None:
        """Test case for aws_tidy_identity_whitelist

        """
        pass

    def test_aws_tidy_role_tag_blacklist(self) -> None:
        """Test case for aws_tidy_role_tag_blacklist

        """
        pass

    def test_aws_tidy_role_tag_deny_list(self) -> None:
        """Test case for aws_tidy_role_tag_deny_list

        """
        pass

    def test_aws_write_auth_role(self) -> None:
        """Test case for aws_write_auth_role

        """
        pass

    def test_aws_write_role_tag(self) -> None:
        """Test case for aws_write_role_tag

        """
        pass

    def test_aws_write_role_tag_blacklist(self) -> None:
        """Test case for aws_write_role_tag_blacklist

        """
        pass

    def test_aws_write_role_tag_deny_list(self) -> None:
        """Test case for aws_write_role_tag_deny_list

        """
        pass

    def test_aws_write_sts_role(self) -> None:
        """Test case for aws_write_sts_role

        """
        pass

    def test_azure_configure_auth(self) -> None:
        """Test case for azure_configure_auth

        """
        pass

    def test_azure_delete_auth_configuration(self) -> None:
        """Test case for azure_delete_auth_configuration

        """
        pass

    def test_azure_delete_auth_role(self) -> None:
        """Test case for azure_delete_auth_role

        """
        pass

    def test_azure_list_auth_roles(self) -> None:
        """Test case for azure_list_auth_roles

        """
        pass

    def test_azure_login(self) -> None:
        """Test case for azure_login

        """
        pass

    def test_azure_read_auth_configuration(self) -> None:
        """Test case for azure_read_auth_configuration

        """
        pass

    def test_azure_read_auth_role(self) -> None:
        """Test case for azure_read_auth_role

        """
        pass

    def test_azure_rotate_root_credentials(self) -> None:
        """Test case for azure_rotate_root_credentials

        """
        pass

    def test_azure_write_auth_role(self) -> None:
        """Test case for azure_write_auth_role

        """
        pass

    def test_centrify_configure(self) -> None:
        """Test case for centrify_configure

        """
        pass

    def test_centrify_login(self) -> None:
        """Test case for centrify_login

        Log in with a username and password.
        """
        pass

    def test_centrify_read_configuration(self) -> None:
        """Test case for centrify_read_configuration

        """
        pass

    def test_cert_configure(self) -> None:
        """Test case for cert_configure

        """
        pass

    def test_cert_delete_certificate(self) -> None:
        """Test case for cert_delete_certificate

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_delete_crl(self) -> None:
        """Test case for cert_delete_crl

        Manage Certificate Revocation Lists checked during authentication.
        """
        pass

    def test_cert_list_certificates(self) -> None:
        """Test case for cert_list_certificates

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_list_crls(self) -> None:
        """Test case for cert_list_crls

        """
        pass

    def test_cert_login(self) -> None:
        """Test case for cert_login

        """
        pass

    def test_cert_read_certificate(self) -> None:
        """Test case for cert_read_certificate

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_read_configuration(self) -> None:
        """Test case for cert_read_configuration

        """
        pass

    def test_cert_read_crl(self) -> None:
        """Test case for cert_read_crl

        Manage Certificate Revocation Lists checked during authentication.
        """
        pass

    def test_cert_write_certificate(self) -> None:
        """Test case for cert_write_certificate

        Manage trusted certificates used for authentication.
        """
        pass

    def test_cert_write_crl(self) -> None:
        """Test case for cert_write_crl

        Manage Certificate Revocation Lists checked during authentication.
        """
        pass

    def test_cloud_foundry_configure(self) -> None:
        """Test case for cloud_foundry_configure

        """
        pass

    def test_cloud_foundry_delete_configuration(self) -> None:
        """Test case for cloud_foundry_delete_configuration

        """
        pass

    def test_cloud_foundry_delete_role(self) -> None:
        """Test case for cloud_foundry_delete_role

        """
        pass

    def test_cloud_foundry_list_roles(self) -> None:
        """Test case for cloud_foundry_list_roles

        """
        pass

    def test_cloud_foundry_login(self) -> None:
        """Test case for cloud_foundry_login

        """
        pass

    def test_cloud_foundry_read_configuration(self) -> None:
        """Test case for cloud_foundry_read_configuration

        """
        pass

    def test_cloud_foundry_read_role(self) -> None:
        """Test case for cloud_foundry_read_role

        """
        pass

    def test_cloud_foundry_write_role(self) -> None:
        """Test case for cloud_foundry_write_role

        """
        pass

    def test_github_configure(self) -> None:
        """Test case for github_configure

        """
        pass

    def test_github_delete_team_mapping(self) -> None:
        """Test case for github_delete_team_mapping

        Read/write/delete a single teams mapping
        """
        pass

    def test_github_delete_user_mapping(self) -> None:
        """Test case for github_delete_user_mapping

        Read/write/delete a single users mapping
        """
        pass

    def test_github_list_teams(self) -> None:
        """Test case for github_list_teams

        Read mappings for teams
        """
        pass

    def test_github_list_teams2(self) -> None:
        """Test case for github_list_teams2

        Read mappings for teams
        """
        pass

    def test_github_list_users(self) -> None:
        """Test case for github_list_users

        Read mappings for users
        """
        pass

    def test_github_list_users2(self) -> None:
        """Test case for github_list_users2

        Read mappings for users
        """
        pass

    def test_github_login(self) -> None:
        """Test case for github_login

        """
        pass

    def test_github_read_configuration(self) -> None:
        """Test case for github_read_configuration

        """
        pass

    def test_github_read_team_mapping(self) -> None:
        """Test case for github_read_team_mapping

        Read/write/delete a single teams mapping
        """
        pass

    def test_github_read_user_mapping(self) -> None:
        """Test case for github_read_user_mapping

        Read/write/delete a single users mapping
        """
        pass

    def test_github_write_team_mapping(self) -> None:
        """Test case for github_write_team_mapping

        Read/write/delete a single teams mapping
        """
        pass

    def test_github_write_user_mapping(self) -> None:
        """Test case for github_write_user_mapping

        Read/write/delete a single users mapping
        """
        pass

    def test_google_cloud_configure_auth(self) -> None:
        """Test case for google_cloud_configure_auth

        """
        pass

    def test_google_cloud_delete_role(self) -> None:
        """Test case for google_cloud_delete_role

        Create a GCP role with associated policies and required attributes.
        """
        pass

    def test_google_cloud_edit_labels_for_role(self) -> None:
        """Test case for google_cloud_edit_labels_for_role

        Add or remove labels for an existing 'gce' role
        """
        pass

    def test_google_cloud_edit_service_accounts_for_role(self) -> None:
        """Test case for google_cloud_edit_service_accounts_for_role

        Add or remove service accounts for an existing `iam` role
        """
        pass

    def test_google_cloud_list_roles(self) -> None:
        """Test case for google_cloud_list_roles

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_google_cloud_list_roles2(self) -> None:
        """Test case for google_cloud_list_roles2

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_google_cloud_login(self) -> None:
        """Test case for google_cloud_login

        """
        pass

    def test_google_cloud_read_auth_configuration(self) -> None:
        """Test case for google_cloud_read_auth_configuration

        """
        pass

    def test_google_cloud_read_role(self) -> None:
        """Test case for google_cloud_read_role

        Create a GCP role with associated policies and required attributes.
        """
        pass

    def test_google_cloud_write_role(self) -> None:
        """Test case for google_cloud_write_role

        Create a GCP role with associated policies and required attributes.
        """
        pass

    def test_jwt_configure(self) -> None:
        """Test case for jwt_configure

        Configure the JWT authentication backend.
        """
        pass

    def test_jwt_delete_role(self) -> None:
        """Test case for jwt_delete_role

        Delete an existing role.
        """
        pass

    def test_jwt_list_roles(self) -> None:
        """Test case for jwt_list_roles

        Lists all the roles registered with the backend.
        """
        pass

    def test_jwt_login(self) -> None:
        """Test case for jwt_login

        Authenticates to Vault using a JWT (or OIDC) token.
        """
        pass

    def test_jwt_oidc_callback(self) -> None:
        """Test case for jwt_oidc_callback

        Callback endpoint to complete an OIDC login.
        """
        pass

    def test_jwt_oidc_callback_form_post(self) -> None:
        """Test case for jwt_oidc_callback_form_post

        Callback endpoint to handle form_posts.
        """
        pass

    def test_jwt_oidc_request_authorization_url(self) -> None:
        """Test case for jwt_oidc_request_authorization_url

        Request an authorization URL to start an OIDC login flow.
        """
        pass

    def test_jwt_read_configuration(self) -> None:
        """Test case for jwt_read_configuration

        Read the current JWT authentication backend configuration.
        """
        pass

    def test_jwt_read_role(self) -> None:
        """Test case for jwt_read_role

        Read an existing role.
        """
        pass

    def test_jwt_write_role(self) -> None:
        """Test case for jwt_write_role

        Register an role with the backend.
        """
        pass

    def test_kerberos_configure(self) -> None:
        """Test case for kerberos_configure

        """
        pass

    def test_kerberos_configure_ldap(self) -> None:
        """Test case for kerberos_configure_ldap

        """
        pass

    def test_kerberos_delete_group(self) -> None:
        """Test case for kerberos_delete_group

        """
        pass

    def test_kerberos_list_groups(self) -> None:
        """Test case for kerberos_list_groups

        """
        pass

    def test_kerberos_login(self) -> None:
        """Test case for kerberos_login

        """
        pass

    def test_kerberos_login2(self) -> None:
        """Test case for kerberos_login2

        """
        pass

    def test_kerberos_read_configuration(self) -> None:
        """Test case for kerberos_read_configuration

        """
        pass

    def test_kerberos_read_group(self) -> None:
        """Test case for kerberos_read_group

        """
        pass

    def test_kerberos_read_ldap_configuration(self) -> None:
        """Test case for kerberos_read_ldap_configuration

        """
        pass

    def test_kerberos_write_group(self) -> None:
        """Test case for kerberos_write_group

        """
        pass

    def test_kubernetes_configure_auth(self) -> None:
        """Test case for kubernetes_configure_auth

        """
        pass

    def test_kubernetes_delete_auth_role(self) -> None:
        """Test case for kubernetes_delete_auth_role

        Register an role with the backend.
        """
        pass

    def test_kubernetes_list_auth_roles(self) -> None:
        """Test case for kubernetes_list_auth_roles

        Lists all the roles registered with the backend.
        """
        pass

    def test_kubernetes_login(self) -> None:
        """Test case for kubernetes_login

        Authenticates Kubernetes service accounts with Vault.
        """
        pass

    def test_kubernetes_read_auth_configuration(self) -> None:
        """Test case for kubernetes_read_auth_configuration

        """
        pass

    def test_kubernetes_read_auth_role(self) -> None:
        """Test case for kubernetes_read_auth_role

        Register an role with the backend.
        """
        pass

    def test_kubernetes_write_auth_role(self) -> None:
        """Test case for kubernetes_write_auth_role

        Register an role with the backend.
        """
        pass

    def test_ldap_configure_auth(self) -> None:
        """Test case for ldap_configure_auth

        """
        pass

    def test_ldap_delete_group(self) -> None:
        """Test case for ldap_delete_group

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_delete_user(self) -> None:
        """Test case for ldap_delete_user

        Manage users allowed to authenticate.
        """
        pass

    def test_ldap_list_groups(self) -> None:
        """Test case for ldap_list_groups

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_list_users(self) -> None:
        """Test case for ldap_list_users

        Manage users allowed to authenticate.
        """
        pass

    def test_ldap_login(self) -> None:
        """Test case for ldap_login

        Log in with a username and password.
        """
        pass

    def test_ldap_read_auth_configuration(self) -> None:
        """Test case for ldap_read_auth_configuration

        """
        pass

    def test_ldap_read_group(self) -> None:
        """Test case for ldap_read_group

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_read_user(self) -> None:
        """Test case for ldap_read_user

        Manage users allowed to authenticate.
        """
        pass

    def test_ldap_write_group(self) -> None:
        """Test case for ldap_write_group

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_ldap_write_user(self) -> None:
        """Test case for ldap_write_user

        Manage users allowed to authenticate.
        """
        pass

    def test_oci_configure(self) -> None:
        """Test case for oci_configure

        """
        pass

    def test_oci_delete_configuration(self) -> None:
        """Test case for oci_delete_configuration

        """
        pass

    def test_oci_delete_role(self) -> None:
        """Test case for oci_delete_role

        Create a role and associate policies to it.
        """
        pass

    def test_oci_list_roles(self) -> None:
        """Test case for oci_list_roles

        Lists all the roles that are registered with Vault.
        """
        pass

    def test_oci_login(self) -> None:
        """Test case for oci_login

        Authenticates to Vault using OCI credentials
        """
        pass

    def test_oci_read_configuration(self) -> None:
        """Test case for oci_read_configuration

        """
        pass

    def test_oci_read_role(self) -> None:
        """Test case for oci_read_role

        Create a role and associate policies to it.
        """
        pass

    def test_oci_write_role(self) -> None:
        """Test case for oci_write_role

        Create a role and associate policies to it.
        """
        pass

    def test_okta_configure(self) -> None:
        """Test case for okta_configure

        """
        pass

    def test_okta_delete_group(self) -> None:
        """Test case for okta_delete_group

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_delete_user(self) -> None:
        """Test case for okta_delete_user

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_okta_list_groups(self) -> None:
        """Test case for okta_list_groups

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_list_users(self) -> None:
        """Test case for okta_list_users

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_okta_login(self) -> None:
        """Test case for okta_login

        Log in with a username and password.
        """
        pass

    def test_okta_read_configuration(self) -> None:
        """Test case for okta_read_configuration

        """
        pass

    def test_okta_read_group(self) -> None:
        """Test case for okta_read_group

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_read_user(self) -> None:
        """Test case for okta_read_user

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_okta_verify(self) -> None:
        """Test case for okta_verify

        """
        pass

    def test_okta_write_group(self) -> None:
        """Test case for okta_write_group

        Manage users allowed to authenticate.
        """
        pass

    def test_okta_write_user(self) -> None:
        """Test case for okta_write_user

        Manage additional groups for users allowed to authenticate.
        """
        pass

    def test_radius_configure(self) -> None:
        """Test case for radius_configure

        """
        pass

    def test_radius_delete_user(self) -> None:
        """Test case for radius_delete_user

        Manage users allowed to authenticate.
        """
        pass

    def test_radius_list_users(self) -> None:
        """Test case for radius_list_users

        Manage users allowed to authenticate.
        """
        pass

    def test_radius_login(self) -> None:
        """Test case for radius_login

        Log in with a username and password.
        """
        pass

    def test_radius_login_with_username(self) -> None:
        """Test case for radius_login_with_username

        Log in with a username and password.
        """
        pass

    def test_radius_read_configuration(self) -> None:
        """Test case for radius_read_configuration

        """
        pass

    def test_radius_read_user(self) -> None:
        """Test case for radius_read_user

        Manage users allowed to authenticate.
        """
        pass

    def test_radius_write_user(self) -> None:
        """Test case for radius_write_user

        Manage users allowed to authenticate.
        """
        pass

    def test_token_create(self) -> None:
        """Test case for token_create

        The token create path is used to create new tokens.
        """
        pass

    def test_token_create_against_role(self) -> None:
        """Test case for token_create_against_role

        This token create path is used to create new tokens adhering to the given role.
        """
        pass

    def test_token_create_orphan(self) -> None:
        """Test case for token_create_orphan

        The token create path is used to create new orphan tokens.
        """
        pass

    def test_token_delete_role(self) -> None:
        """Test case for token_delete_role

        """
        pass

    def test_token_list_accessors(self) -> None:
        """Test case for token_list_accessors

        List token accessors, which can then be be used to iterate and discover their properties or revoke them. Because this can be used to cause a denial of service, this endpoint requires 'sudo' capability in addition to 'list'.
        """
        pass

    def test_token_list_roles(self) -> None:
        """Test case for token_list_roles

        This endpoint lists configured roles.
        """
        pass

    def test_token_look_up(self) -> None:
        """Test case for token_look_up

        """
        pass

    def test_token_look_up2(self) -> None:
        """Test case for token_look_up2

        """
        pass

    def test_token_look_up_accessor(self) -> None:
        """Test case for token_look_up_accessor

        This endpoint will lookup a token associated with the given accessor and its properties. Response will not contain the token ID.
        """
        pass

    def test_token_look_up_self(self) -> None:
        """Test case for token_look_up_self

        """
        pass

    def test_token_look_up_self2(self) -> None:
        """Test case for token_look_up_self2

        """
        pass

    def test_token_read_role(self) -> None:
        """Test case for token_read_role

        """
        pass

    def test_token_renew(self) -> None:
        """Test case for token_renew

        This endpoint will renew the given token and prevent expiration.
        """
        pass

    def test_token_renew_accessor(self) -> None:
        """Test case for token_renew_accessor

        This endpoint will renew a token associated with the given accessor and its properties. Response will not contain the token ID.
        """
        pass

    def test_token_renew_self(self) -> None:
        """Test case for token_renew_self

        This endpoint will renew the token used to call it and prevent expiration.
        """
        pass

    def test_token_revoke(self) -> None:
        """Test case for token_revoke

        This endpoint will delete the given token and all of its child tokens.
        """
        pass

    def test_token_revoke_accessor(self) -> None:
        """Test case for token_revoke_accessor

        This endpoint will delete the token associated with the accessor and all of its child tokens.
        """
        pass

    def test_token_revoke_orphan(self) -> None:
        """Test case for token_revoke_orphan

        This endpoint will delete the token and orphan its child tokens.
        """
        pass

    def test_token_revoke_self(self) -> None:
        """Test case for token_revoke_self

        This endpoint will delete the token used to call it and all of its child tokens.
        """
        pass

    def test_token_tidy(self) -> None:
        """Test case for token_tidy

        This endpoint performs cleanup tasks that can be run if certain error conditions have occurred.
        """
        pass

    def test_token_write_role(self) -> None:
        """Test case for token_write_role

        """
        pass

    def test_userpass_delete_user(self) -> None:
        """Test case for userpass_delete_user

        Manage users allowed to authenticate.
        """
        pass

    def test_userpass_list_users(self) -> None:
        """Test case for userpass_list_users

        Manage users allowed to authenticate.
        """
        pass

    def test_userpass_login(self) -> None:
        """Test case for userpass_login

        Log in with a username and password.
        """
        pass

    def test_userpass_read_user(self) -> None:
        """Test case for userpass_read_user

        Manage users allowed to authenticate.
        """
        pass

    def test_userpass_reset_password(self) -> None:
        """Test case for userpass_reset_password

        Reset user's password.
        """
        pass

    def test_userpass_update_policies(self) -> None:
        """Test case for userpass_update_policies

        Update the policies associated with the username.
        """
        pass

    def test_userpass_write_user(self) -> None:
        """Test case for userpass_write_user

        Manage users allowed to authenticate.
        """
        pass


if __name__ == '__main__':
    unittest.main()
