# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_write_role_response import PkiWriteRoleResponse

class TestPkiWriteRoleResponse(unittest.TestCase):
    """PkiWriteRoleResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiWriteRoleResponse:
        """Test PkiWriteRoleResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiWriteRoleResponse`
        """
        model = PkiWriteRoleResponse()
        if include_optional:
            return PkiWriteRoleResponse(
                allow_any_name = True,
                allow_bare_domains = True,
                allow_glob_domains = True,
                allow_ip_sans = True,
                allow_localhost = True,
                allow_subdomains = True,
                allow_token_displayname = True,
                allow_wildcard_certificates = True,
                allowed_domains = [
                    ''
                    ],
                allowed_domains_template = True,
                allowed_other_sans = [
                    ''
                    ],
                allowed_serial_numbers = [
                    ''
                    ],
                allowed_uri_sans = [
                    ''
                    ],
                allowed_uri_sans_template = True,
                allowed_user_ids = [
                    ''
                    ],
                basic_constraints_valid_for_non_ca = True,
                client_flag = True,
                cn_validations = [
                    ''
                    ],
                code_signing_flag = True,
                country = [
                    ''
                    ],
                email_protection_flag = True,
                enforce_hostnames = True,
                ext_key_usage = [
                    ''
                    ],
                ext_key_usage_oids = [
                    ''
                    ],
                generate_lease = True,
                issuer_ref = '',
                key_bits = 56,
                key_type = '',
                key_usage = [
                    ''
                    ],
                locality = [
                    ''
                    ],
                max_ttl = 56,
                no_store = True,
                not_after = '',
                not_before_duration = 56,
                organization = [
                    ''
                    ],
                ou = [
                    ''
                    ],
                policy_identifiers = [
                    ''
                    ],
                postal_code = [
                    ''
                    ],
                province = [
                    ''
                    ],
                require_cn = True,
                server_flag = True,
                signature_bits = 56,
                street_address = [
                    ''
                    ],
                ttl = 56,
                use_csr_common_name = True,
                use_csr_sans = True,
                use_pss = True
            )
        else:
            return PkiWriteRoleResponse(
        )
        """

    def testPkiWriteRoleResponse(self):
        """Test PkiWriteRoleResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
