# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class LeaderStatusResponse(BaseModel):
    """
    LeaderStatusResponse
    """ # noqa: E501
    active_time: Optional[datetime] = None
    ha_enabled: Optional[StrictBool] = None
    is_self: Optional[StrictBool] = None
    last_wal: Optional[StrictInt] = None
    leader_address: Optional[StrictStr] = None
    leader_cluster_address: Optional[StrictStr] = None
    performance_standby: Optional[StrictBool] = None
    performance_standby_last_remote_wal: Optional[StrictInt] = None
    raft_applied_index: Optional[StrictInt] = None
    raft_committed_index: Optional[StrictInt] = None
    __properties: ClassVar[List[str]] = ["active_time", "ha_enabled", "is_self", "last_wal", "leader_address", "leader_cluster_address", "performance_standby", "performance_standby_last_remote_wal", "raft_applied_index", "raft_committed_index"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LeaderStatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LeaderStatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "active_time": obj.get("active_time"),
            "ha_enabled": obj.get("ha_enabled"),
            "is_self": obj.get("is_self"),
            "last_wal": obj.get("last_wal"),
            "leader_address": obj.get("leader_address"),
            "leader_cluster_address": obj.get("leader_cluster_address"),
            "performance_standby": obj.get("performance_standby"),
            "performance_standby_last_remote_wal": obj.get("performance_standby_last_remote_wal"),
            "raft_applied_index": obj.get("raft_applied_index"),
            "raft_committed_index": obj.get("raft_committed_index")
        })
        return _obj


