# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PkiRevokeIssuerResponse(BaseModel):
    """
    PkiRevokeIssuerResponse
    """ # noqa: E501
    ca_chain: Optional[List[StrictStr]] = Field(default=None, description="Certificate Authority Chain")
    certificate: Optional[StrictStr] = Field(default=None, description="Certificate")
    crl_distribution_points: Optional[List[StrictStr]] = Field(default=None, description="Specifies the URL values for the CRL Distribution Points field")
    issuer_id: Optional[StrictStr] = Field(default=None, description="ID of the issuer")
    issuer_name: Optional[StrictStr] = Field(default=None, description="Name of the issuer")
    issuing_certificates: Optional[List[StrictStr]] = Field(default=None, description="Specifies the URL values for the Issuing Certificate field")
    key_id: Optional[StrictStr] = Field(default=None, description="ID of the Key")
    leaf_not_after_behavior: Optional[StrictStr] = None
    manual_chain: Optional[List[StrictStr]] = Field(default=None, description="Manual Chain")
    ocsp_servers: Optional[List[StrictStr]] = Field(default=None, description="Specifies the URL values for the OCSP Servers field")
    revocation_signature_algorithm: Optional[StrictStr] = Field(default=None, description="Which signature algorithm to use when building CRLs")
    revocation_time: Optional[StrictInt] = Field(default=None, description="Time of revocation")
    revocation_time_rfc3339: Optional[datetime] = Field(default=None, description="RFC formatted time of revocation")
    revoked: Optional[StrictBool] = Field(default=None, description="Whether the issuer was revoked")
    usage: Optional[StrictStr] = Field(default=None, description="Allowed usage")
    __properties: ClassVar[List[str]] = ["ca_chain", "certificate", "crl_distribution_points", "issuer_id", "issuer_name", "issuing_certificates", "key_id", "leaf_not_after_behavior", "manual_chain", "ocsp_servers", "revocation_signature_algorithm", "revocation_time", "revocation_time_rfc3339", "revoked", "usage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PkiRevokeIssuerResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PkiRevokeIssuerResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ca_chain": obj.get("ca_chain"),
            "certificate": obj.get("certificate"),
            "crl_distribution_points": obj.get("crl_distribution_points"),
            "issuer_id": obj.get("issuer_id"),
            "issuer_name": obj.get("issuer_name"),
            "issuing_certificates": obj.get("issuing_certificates"),
            "key_id": obj.get("key_id"),
            "leaf_not_after_behavior": obj.get("leaf_not_after_behavior"),
            "manual_chain": obj.get("manual_chain"),
            "ocsp_servers": obj.get("ocsp_servers"),
            "revocation_signature_algorithm": obj.get("revocation_signature_algorithm"),
            "revocation_time": obj.get("revocation_time"),
            "revocation_time_rfc3339": obj.get("revocation_time_rfc3339"),
            "revoked": obj.get("revoked"),
            "usage": obj.get("usage")
        })
        return _obj


