# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.mounts_read_tuning_information_response import MountsReadTuningInformationResponse

class TestMountsReadTuningInformationResponse(unittest.TestCase):
    """MountsReadTuningInformationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MountsReadTuningInformationResponse:
        """Test MountsReadTuningInformationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `MountsReadTuningInformationResponse`
        """
        model = MountsReadTuningInformationResponse()
        if include_optional:
            return MountsReadTuningInformationResponse(
                allowed_managed_keys = [
                    ''
                    ],
                allowed_response_headers = [
                    ''
                    ],
                audit_non_hmac_request_keys = [
                    ''
                    ],
                audit_non_hmac_response_keys = [
                    ''
                    ],
                default_lease_ttl = 56,
                description = '',
                external_entropy_access = True,
                force_no_cache = True,
                listing_visibility = '',
                max_lease_ttl = 56,
                options = None,
                passthrough_request_headers = [
                    ''
                    ],
                plugin_version = '',
                token_type = '',
                user_lockout_counter_reset_duration = 56,
                user_lockout_disable = True,
                user_lockout_duration = 56,
                user_lockout_threshold = 56
            )
        else:
            return MountsReadTuningInformationResponse(
        )
        """

    def testMountsReadTuningInformationResponse(self):
        """Test MountsReadTuningInformationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
