# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.pki_read_issuer_response import PkiReadIssuerResponse

class TestPkiReadIssuerResponse(unittest.TestCase):
    """PkiReadIssuerResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PkiReadIssuerResponse:
        """Test PkiReadIssuerResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PkiReadIssuerResponse`
        """
        model = PkiReadIssuerResponse()
        if include_optional:
            return PkiReadIssuerResponse(
                ca_chain = [
                    ''
                    ],
                certificate = '',
                crl_distribution_points = [
                    ''
                    ],
                enable_aia_url_templating = True,
                issuer_id = '',
                issuer_name = '',
                issuing_certificates = [
                    ''
                    ],
                key_id = '',
                leaf_not_after_behavior = '',
                manual_chain = [
                    ''
                    ],
                ocsp_servers = [
                    ''
                    ],
                revocation_signature_algorithm = '',
                revocation_time = 56,
                revocation_time_rfc3339 = '',
                revoked = True,
                usage = ''
            )
        else:
            return PkiReadIssuerResponse(
        )
        """

    def testPkiReadIssuerResponse(self):
        """Test PkiReadIssuerResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
