# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.ssh_write_role_request import SshWriteRoleRequest

class TestSshWriteRoleRequest(unittest.TestCase):
    """SshWriteRoleRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SshWriteRoleRequest:
        """Test SshWriteRoleRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SshWriteRoleRequest`
        """
        model = SshWriteRoleRequest()
        if include_optional:
            return SshWriteRoleRequest(
                algorithm_signer = '',
                allow_bare_domains = True,
                allow_host_certificates = True,
                allow_subdomains = True,
                allow_user_certificates = True,
                allow_user_key_ids = True,
                allowed_critical_options = '',
                allowed_domains = '',
                allowed_domains_template = True,
                allowed_extensions = '',
                allowed_user_key_lengths = None,
                allowed_users = '',
                allowed_users_template = True,
                cidr_list = '',
                default_critical_options = None,
                default_extensions = None,
                default_extensions_template = True,
                default_user = '',
                default_user_template = True,
                exclude_cidr_list = '',
                key_id_format = '',
                key_type = 'otp',
                max_ttl = '',
                not_before_duration = '30',
                port = 56,
                ttl = ''
            )
        else:
            return SshWriteRoleRequest(
        )
        """

    def testSshWriteRoleRequest(self):
        """Test SshWriteRoleRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
