# coding: utf-8

"""
    HashiCorp Vault API

    HTTP API that gives you full access to Vault. All API routes are prefixed with `/v1/`.

    The version of the OpenAPI document: 1.15.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from ahvac.models.jwt_oidc_callback_form_post_request import JwtOidcCallbackFormPostRequest

class TestJwtOidcCallbackFormPostRequest(unittest.TestCase):
    """JwtOidcCallbackFormPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> JwtOidcCallbackFormPostRequest:
        """Test JwtOidcCallbackFormPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `JwtOidcCallbackFormPostRequest`
        """
        model = JwtOidcCallbackFormPostRequest()
        if include_optional:
            return JwtOidcCallbackFormPostRequest(
                client_nonce = '',
                code = '',
                id_token = '',
                state = ''
            )
        else:
            return JwtOidcCallbackFormPostRequest(
        )
        """

    def testJwtOidcCallbackFormPostRequest(self):
        """Test JwtOidcCallbackFormPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
